#!/usr/bin/python3

import numpy as np
import matplotlib as mpl
mpl.use('Agg')                    # For plotting without X server
import matplotlib.pyplot as plt
import sys
import os.path

# Read the MD data (t, left-top, left-bot, right-top, right-bot)
DataMD = np.loadtxt("00_get_CL_coordinates.txt")

# Plot the contact line locations
plt.figure(1, figsize=(12, 6.75), dpi=160)
plt.cla()
plt.plot(DataMD[:,0],DataMD[:,1],'g-.',label="MD, left-top")
plt.plot(DataMD[:,0],DataMD[:,2],'r-.',label="MD, left-bot")
plt.title("CL coordinate evolution in time, MD")
plt.xlabel("t [ps]")
plt.ylabel(r"$x_{cl}$ [nm]")
plt.legend(loc="lower right")
# plt.ylim([0.0,9.0])
# plt.xlim([0.0,15900])
plt.savefig("01_check_CLloc_displacement_clCoord_left.pdf", format="pdf")

plt.figure(2, figsize=(12, 6.75), dpi=160)
plt.cla()
plt.plot(DataMD[:,0],DataMD[:,3],'b-.',label="MD, right-top")
plt.plot(DataMD[:,0],DataMD[:,4],'k-.',label="MD, right-bot")
plt.title("CL coordinate evolution in time, MD")
plt.xlabel("t [ps]")
plt.ylabel(r"$x_{cl}$ [nm]")
plt.legend(loc="lower right")
# plt.ylim([0.0,9.0])
# plt.xlim([0.0,15900])
plt.savefig("01_check_CLloc_displacement_clCoord_right.pdf", format="pdf")


# Create left and right drop displacement arrays
DataDx = np.copy(DataMD)
DataDx[:,1] = DataMD[:,1]-DataMD[:,2]
DataDx[:,2] = DataMD[:,3]-DataMD[:,4]
DataDx[:,3] = 0.5*(DataDx[:,1]+DataDx[:,2])

# Do an average
leftT = 6000 # Start time in pico-seconds
# leftT = 0 # Start time in pico-seconds
indL = (DataMD[:,0]>leftT).nonzero()[0][0]
print("Selected start index (time %d ps) for averaging: %d"%(leftT,indL))
print("  Number of averaging files: %d"%(len(DataMD[:,0])-indL))
meanL = np.mean(DataDx[indL:-1,1])
meanR = np.mean(DataDx[indL:-1,2])
meanA = np.mean(DataDx[indL:-1,3])
print("Mean displacement values:")
print("     left: %.2f nm"%meanL)
print("    right: %.2f nm"%meanR)
print("   averge: %.2f nm"%meanA)


# Do the plotting, save figure
plt.figure(3, figsize=(12, 6.75), dpi=160)
plt.cla()
plt.plot(DataMD[:,0],DataDx[:,1],'g--',label="MD, left")
plt.plot(DataMD[:,0],DataDx[:,2],'r--',label="MD, right")
plt.plot(DataMD[:,0],DataDx[:,3],'k-',label="MD, avg")
plt.plot([0,np.max(DataMD[:,0])],[meanL,meanL],'g:')
plt.plot([0,np.max(DataMD[:,0])],[meanR,meanR],'r:')
plt.plot([0,np.max(DataMD[:,0])],[meanA,meanA],'k:')
plt.title("Drop displacement evolution in time, MD, rough estimation")
plt.xlabel("t [ps]")
plt.ylabel(r"$\Delta x$ [nm]")
plt.legend(loc="lower right")
# plt.ylim([0.0,9.0])
# plt.xlim([0.0,15900])
plt.savefig("01_check_CLloc_displacement_dx.pdf", format="pdf")

# Plot along the second way of extracting drop displacement
DataMDi = np.loadtxt("00_get_CL_coordinates_Idx.txt")
plt.figure(4, figsize=(12, 6.75), dpi=160)
plt.cla()
plt.plot(DataMD[:,0],DataDx[:,3],'k-',label="MD, avg")
plt.plot(DataMDi[:,0],DataMDi[:,1],'g:',label="MD, interpolation")
plt.plot([0,np.max(DataMD[:,0])],[meanA,meanA],'k:')
plt.title("Drop displacement evolution in time, MD, rough estimation")
plt.xlabel("t [ps]")
plt.ylabel(r"$\Delta x$ [nm]")
plt.legend(loc="lower right")
# plt.ylim([0.0,9.0])
# plt.xlim([0.0,15900])
plt.savefig("01_check_CLloc_displacement_Idx.pdf", format="pdf")



plt.show()
