#!/usr/bin/python3

import numpy as np
import matplotlib.pyplot as plt
import sys

plt.rcParams['text.usetex']=True
plt.rcParams.update({'figure.autolayout': True})  # to make sure that labels are inside printing area

font = {'family' : 'DejaVu Sans',
        'weight' : 'bold',
        'size'   : 18}

plt.rc('font', **font)

# Set the vertical bin index to use
idY = 6
# idY = 6 # here we start looking at interfaces!!!
# idY = 151-3

# Read the bin array data
Xar = np.loadtxt("../02_Xmatrix.txt")
Yar = np.loadtxt("../02_Ymatrix.txt")
Nx  = np.shape(Xar)[0]
Ny  = np.shape(Xar)[1]

print("Read file with Nx = %d, Ny = %d bins! Measurement units: nm"%(Nx,Ny))

# Read the density array
Mar = np.loadtxt("../02_average_wMcent_Mmatrix.txt")

# Display the minimum and maximum binning coordinates
bin_dx = Xar[1,0]-Xar[0,0]
bin_dy = Yar[0,1]-Yar[0,0]
print("x in [%f, %f], dx = %f"%(Xar[0,0],Xar[Nx-1,0],bin_dx))
print("y in [%f, %f], dy = %f"%(Yar[0,0],Yar[0,Ny-1],bin_dy))

# Bin volume in m^3
binVol = bin_dx*bin_dy*4.67650*1e-27
# Atomic mass unit normalisation of M
binVol = binVol/1.6605402e-27


# print(Xar[1:5,4])
# print(Yar[1:5,1])
# # # print(len(MDflow['Y']))
# # # print(len(MDflow['M']))

# # Try some outputs
# print("%.3f, %.3f"%(MDflow[1,4]["X"],MDflow[1,4]["U"]))

# Do the plotting, save figure
plt.figure(1, figsize=(12, 6.75), dpi=160)
plt.plot(Xar[:,idY],Mar[:,idY],'g-',label="MD, bottom wall")
plt.title("Density slice (averaged), idY = %d, y = %f nm"%(idY,Yar[0,idY]))
plt.xlabel("x [nm]")
plt.ylabel(r"$\rho_w$ [kg/m$^3$]")
# plt.legend(loc="lower right")
# plt.ylim([-1.5,5.5])
# plt.xlim([0.0,32000])
plt.savefig("Slice_density_yind%03d.pdf"%idY, format="pdf")
plt.show()
