#!/usr/bin/python3

import numpy as np
import sys

# fraction of bulk/mean density to define the interface point
dItf = 0.5
dAvg = 0.10 # This is over-riden later in the file
cAvg = 0.10 # Criterion for slice density average computation close to wall
# Bulk density in kg/m3
blkDen = 986

# Number of bins to skip, purely based on how much density we have accessible near the wall
nSkp = 3

# Read the bin array data
Xar = np.loadtxt("../02_Xmatrix.txt")
Yar = np.loadtxt("../02_Ymatrix.txt")
Nx  = np.shape(Xar)[0]
Ny  = np.shape(Xar)[1]

print("Read file with Nx = %d, Ny = %d bins! Measurement units: nm"%(Nx,Ny))

# Read the density array
Mar = np.loadtxt("../02_average_wMcent_Mmatrix.txt")

# Display the minimum and maximum binning coordinates
print("x in [%f, %f], dx = %f"%(Xar[0,0],Xar[Nx-1,0],Xar[1,0]-Xar[0,0]))
print("y in [%f, %f], dy = %f"%(Yar[0,0],Yar[0,Ny-1],Yar[0,1]-Yar[0,0]))

# Extract the interface from the averaged density field
IntfData = np.zeros((Ny-2*nSkp,4))
IntfDataR= np.zeros((Ny-2*nSkp,2))
for i in range(Ny-2*nSkp):
    if(i==0 or i==Ny-2*nSkp-1):
        dAvg = cAvg
    else:
        dAvg = 0.10
    # Compute slice average
    iL   = (Mar[:,nSkp+i]>dAvg*blkDen).nonzero()[0][ 0]+10;
    iR   = (Mar[:,nSkp+i]>dAvg*blkDen).nonzero()[0][-1]-10;
    avgS = np.sum(0.5*(Mar[iL+1:iR+1,nSkp+i]+Mar[iL:iR,nSkp+i])*np.diff(Xar[iL:iR+1,nSkp+i]))/(Xar[iR,nSkp+i]-Xar[iL,nSkp+i])
    # Now work on the data
    IntfData[i,1] = Yar[0,nSkp+i]
    iR = (Mar[:,nSkp+i]>dItf*avgS).nonzero()[0][ 0]; iL = iR-1;
    IntfData[i,0] = Xar[iL,nSkp+i] + (Xar[iR,nSkp+i]-Xar[iL,nSkp+i])*(dItf*avgS-Mar[iL,nSkp+i])/(Mar[iR,nSkp+i]-Mar[iL,nSkp+i])
    IntfDataR[i,1] = Yar[0,nSkp+i]
    iL = (Mar[:,nSkp+i]>dItf*avgS).nonzero()[0][-1]; iR = iL+1;
    IntfDataR[i,0] = Xar[iL,nSkp+i] + (Xar[iR,nSkp+i]-Xar[iL,nSkp+i])*(dItf*avgS-Mar[iL,nSkp+i])/(Mar[iR,nSkp+i]-Mar[iL,nSkp+i])

# Mirror the right profile
for k in range(len(IntfDataR[:,0])):
    IntfDataR[k,0] =-IntfDataR[k,0]
    IntfDataR[k,1] =-IntfDataR[k,1]
# Sort by the y coordinates
IntfDataR[:,1] = IntfDataR[:,1] + 35.0
IntfDataR.view('i8,i8').sort(order=['f1'], axis=0)

# Put the mirrored right profile in the data array
IntfData[:,2] = IntfDataR[:,0]

# Compute the average
IntfData[:,3] = 0.5*(IntfData[:,0]+IntfData[:,2])

# Shift all x coordinates to zero at the center of the interface
iMid = int(len(IntfData[:,0])/2)
IntfData[:,0 ] = IntfData[:,0 ] - IntfData[iMid,0 ]
IntfData[:,2:] = IntfData[:,2:] - IntfData[iMid,2:]

# Save the data
np.savetxt("steadyInterface_wMcent.txt", IntfData, header="Steady interface, x(left), y, x(right), x(avg)")

